Development
===========
From the project root, you can run the following commands:

* ``make test``: Run unit tests
* ``make artifacts``: Build all artifacts (sdist, wheel, etc... )
* ``make sdist``: Build a Python sdist
* ``make wheel``: Build a Python wheel
* ``make docs``: Build the HTML documentation
* ``make format-code``: Format the code with ``black``
* ``make publish``: Publish artifacts in dist folder to Pypi
* ``make freeze``: List packages installed in base virtual environment
* ``make clean``: Remove all build files
* ``make env-clean``: Remove all build files and virtual environments
